pub enum Action<M> {
Show 19 variants
AppSubsurface(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
Subsurface(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>),
DestroySubsurface(Id),
AppPopup(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
Popup(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>),
DestroyPopup(Id),
DestroyTooltipPopup,
AppWindow(Id, Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
Window(Id, Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>),
DestroyWindow(Id),
AppLayerShell(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
LayerShell(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>),
DestroyLayerShell(Id),
Lock(Id, WlOutput, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>),
DestroyLock(Id),
ResponsiveMenuBar {
menu_bar: Id,
limits: Limits,
size: Size,
},
Ignore,
SyncLiveSettings(Id),
Task(Arc<dyn Fn() -> Task<Action<M>> + Send + Sync>),
}Expand description
Ignore this message in your application. It will be intercepted.
M is the message type of whoever created the action. The ones prefixed with App take the
application itself and are type-erased, the others carry a View typed on M.
Variants
AppSubsurface(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a subsurface with a view function accepting the App as a parameter
Subsurface(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>)
Create a subsurface with a view function
DestroySubsurface(Id)
Destroy a subsurface with a view function
AppPopup(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a popup with a view function accepting the App as a parameter
Popup(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>)
Create a popup
DestroyPopup(Id)
Destroy a subsurface with a view function
DestroyTooltipPopup
Destroys the global tooltip popup subsurface
AppWindow(Id, Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a window with a view function accepting the App as a parameter
Window(Id, Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>)
Create a window with a view function
DestroyWindow(Id)
Destroy a window
AppLayerShell(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a layer shell surface with a view function accepting the App as a parameter
LayerShell(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>)
Create a layer shell surface with a view function
DestroyLayerShell(Id)
Destroy a layer shell surface
Lock(Id, WlOutput, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<View<M>>)
wayland_platform only.Create a lock shell surface with a view function
DestroyLock(Id)
Destroy a lock surface
ResponsiveMenuBar
Responsive menu bar update
Fields
Id of the menu bar
Ignore
SyncLiveSettings(Id)
Task(Arc<dyn Fn() -> Task<Action<M>> + Send + Sync>)
Implementations