pub enum Action {
Show 17 variants
AppSubsurface(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
Subsurface(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
DestroySubsurface(Id),
AppPopup(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
Popup(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
DestroyPopup(Id),
DestroyTooltipPopup,
AppWindow(Id, Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
Window(Id, Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
DestroyWindow(Id),
AppLayerShell(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
LayerShell(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>),
DestroyLayerShell(Id),
ResponsiveMenuBar {
menu_bar: Id,
limits: Limits,
size: Size,
},
Ignore,
SyncLiveSettings(Id),
Task(Arc<dyn Fn() -> Task<Action> + Send + Sync>),
}Expand description
Ignore this message in your application. It will be intercepted.
Variants
AppSubsurface(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a subsurface with a view function accepting the App as a parameter
Subsurface(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a subsurface with a view function
DestroySubsurface(Id)
Destroy a subsurface with a view function
AppPopup(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a popup with a view function accepting the App as a parameter
Popup(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a popup
DestroyPopup(Id)
Destroy a subsurface with a view function
DestroyTooltipPopup
Destroys the global tooltip popup subsurface
AppWindow(Id, Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a window with a view function accepting the App as a parameter
Window(Id, Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a window with a view function
DestroyWindow(Id)
Destroy a window
AppLayerShell(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a layer shell surface with a view function accepting the App as a parameter
LayerShell(Arc<Box<dyn Any + Send + Sync + 'static>>, Arc<Box<dyn Any + Send + Sync + 'static>>, Option<Arc<Box<dyn Any + Send + Sync + 'static>>>)
Create a layer shell surface with a view function
DestroyLayerShell(Id)
Destroy a layer shell surface
ResponsiveMenuBar
Responsive menu bar update
Fields
Id of the menu bar
Ignore
SyncLiveSettings(Id)
Task(Arc<dyn Fn() -> Task<Action> + Send + Sync>)